.. _index:

==============
repoze.catalog
==============

:mod:`repoze.catalog` is a Python indexing and searching framework.
It relies on :term:`zope.index` and most of its internals are taken
from :term:`zope.app.catalog`.  Unlike ``zope.app.catalog``, however,
it is meant to be useful outside of the larger Zope framework within
arbitrary Python applications.

Narrative documentation
-----------------------

Narrative documentation explaining how to use :mod:`repoze.catalog`.

.. toctree::
   :maxdepth: 2

   overview
   install
   upgrade
   usage
   genealogy
   glossary
   changes

API documentation
-----------------

API documentation for :mod:`repoze.catalog`.

.. toctree::
   :maxdepth: 2

   api

Source Code and Issue Tracking
------------------------------

Source code is available from https://github.com/repoze/repoze.catalog

File bugs via https://github.com/repoze/repoze.catalog/issues

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
* :ref:`glossary`

